import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { CodeartifactClientResolvedConfig } from "../CodeartifactClient";
/**
 * @internal
 */
export interface CodeartifactHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface CodeartifactHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<CodeartifactClientResolvedConfig, HandlerExecutionContext, CodeartifactHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultCodeartifactHttpAuthSchemeParametersProvider: (config: CodeartifactClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<CodeartifactHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface CodeartifactHttpAuthSchemeProvider extends HttpAuthSchemeProvider<CodeartifactHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultCodeartifactHttpAuthSchemeProvider: CodeartifactHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: CodeartifactHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: CodeartifactHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
